package cz.muni.fi.pa165.socialnetwork.facade;

import cz.muni.fi.pa165.socialnetwork.anotation.MethodExecutionTimeTracker;
import cz.muni.fi.pa165.socialnetwork.api.PersonBasicViewDto;
import cz.muni.fi.pa165.socialnetwork.api.PersonDetailedViewDto;
import cz.muni.fi.pa165.socialnetwork.mappers.PersonMapper;
import cz.muni.fi.pa165.socialnetwork.service.PersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
@Transactional
public class PersonFacade {

    private final PersonService personService;
    private final PersonMapper personMapper;

    @Autowired
    public PersonFacade(PersonService personService, PersonMapper personMapper) {
        this.personService = personService;
        this.personMapper = personMapper;
    }

    @Transactional(readOnly = true)
    public PersonDetailedViewDto findById(Long id) {
        return personMapper.mapToDetailViewDto(personService.findById(id));
    }

    @Transactional(readOnly = true)
    @MethodExecutionTimeTracker
    public Page<PersonBasicViewDto> findAll(Pageable pageable) {
        return personMapper.mapToPageDto(personService.findAll(pageable));
    }

}
